@@ -16,7 +16,9 @@ import typing as t
 
 def get_project_path():
     # 获取当前执行文件的绝对路径（兼容 Python 2 和 Python 3）
-    return os.path.abspath(sys.argv[0])
+    exec_file_path = os.path.abspath(sys.argv[0])
+    exec_file_path_slice = exec_file_path.split(os.path.sep)
+    return os.path.sep.join(exec_file_path_slice[:-1])
 
 
 def get_images_dir():
