@@ -16,15 +16,15 @@ import warnings
 import subprocess
 import typing as t
 from poco.proxy import UIObjectProxy
-from airtest.cli.parser import cli_setup
+# from airtest.cli.parser import cli_setup
 from airtest.utils.transform import TargetPos
 
 from poco.drivers.android.uiautomation import AndroidUiautomationPoco
-from airtest.core.api import auto_setup, device, Template, touch, find_all, connect_device
+from airtest.core.api import auto_setup, device, Template, touch, find_all, connect_device, exists
 
-from capp_ui.utils import logger
+from capp_ui.device import cli_setup
 from capp_ui.dir import get_project_path
-from capp_ui.libs import airtest_exception_format
+from capp_ui.libs import airtest_exception_format, logger
 
 iOS_PLATFORM = "iOS"
 DEFAULT_PLATFORM = "Android"  # Android、Windows、iOS
@@ -34,9 +34,9 @@ warnings.filterwarnings("ignore", category=UserWarning,
                         message="Currently using ADB touch, the efficiency may be very low.")
 
 
-def stop_app(app_name, timeout=5):
+def stop_app(app_name, device_id: str, timeout=5):
     # 构造ADB命令
-    adb_cmd = "adb.exe shell am force-stop {}".format(app_name)
+    adb_cmd = "adb.exe -s {} shell am force-stop {}".format(device_id, app_name)
     # 将命令字符串分割成列表
     cmd_list = shlex.split(adb_cmd)
     try:
@@ -51,10 +51,10 @@ def stop_app(app_name, timeout=5):
         logger.error("An error occurred: {}".format(e))
 
 
-def get_screen_size_via_adb():
+def get_screen_size_via_adb(device_id: str):
     # 使用ADB命令获取设备屏幕大小
     try:
-        output = subprocess.check_output(['adb', 'shell', 'wm', 'size']).decode('utf-8')
+        output = subprocess.check_output(['adb', '-s', device_id, 'shell', 'wm', 'size']).decode('utf-8')
         match = re.search(r'Physical size: (\d+)x(\d+)', output)
         if match:
             width = int(match.group(1))
@@ -65,24 +65,42 @@ def get_screen_size_via_adb():
     return None
 
 
+def get_connected_devices():
+    devices = list()
+    try:
+        # 执行 adb 命令获取设备列表信息
+        result = subprocess.run(['adb', 'devices'], capture_output=True, text=True)
+        # 检查是否成功执行 adb 命令
+        if result.returncode == 0:
+            # 解析 adb 输出，获取设备列表信息
+            output_lines = result.stdout.strip().split('\n')
+            # 第一行是标题，需要跳过
+            devices = [line.split('\t')[0] for line in output_lines[1:] if line.strip()]
+        else:
+            logger.error("Failed to execute adb command.")
+    except Exception as e:
+        logger.error(f"An error occurred: {e}")
+    return devices
+
+
 class Phone(object):
 
     def __init__(
             self,
             device_id: str,
-            device_conn: str,
+            port: int = 0,
+            device_conn: str = None,
             platform: str = "Android",
-            enable_debug: bool = False,
+            enable_debug: bool = False
     ) -> None:
         self.platform = platform
         self.device_id = device_id
+        self.port = port
         self.device_conn = device_conn
         self.enable_debug = enable_debug
         self.__init_device()
         self.dev = device()
-        self.poco = AndroidUiautomationPoco(
-            use_airtest_input=True, screenshot_each_action=False
-        )
+        self.poco = None
 
     def __init_device(self) -> None:
         if not cli_setup():
@@ -90,7 +108,7 @@ class Phone(object):
             airtest.utils.compat.DEFAULT_LOG_DIR = "logs"
             airtest.core.settings.Settings.DEBUG = self.enable_debug
             airtest.core.settings.Settings.LOG_FILE = "{}.log".format(self.device_id)
-            if self.device_conn.find(":5555") != -1:
+            if self.port > 0:
                 if self.platform == DEFAULT_PLATFORM:
                     connect_device(self.device_conn)
                 else:
@@ -363,15 +381,14 @@ class Phone(object):
             result = self.dev.wait(v=v, timeout=timeout, interval=interval, intervalfunc=intervalfunc)
         return result or None
 
-    @airtest_exception_format
-    def exists(self, v: Template) -> t.Any:
+    def exists(self, v: Template) -> bool:
         """ "
         检查设备上是否存在给定目标
         v Template: 要检查的目标
         return: 如果未找到目标，则返回False，否则返回目标的坐标
         platform: Android, iOS, Windows
         """
-        result = None
+        result = False
         if self.platform in (DEFAULT_PLATFORM, WINDOWS_PLATFORM, iOS_PLATFORM):
             # if self.device.exists(Template(r"tpl1606822430589.png")):
             #    self.device.touch(Template(r"tpl1606822430589.png"))
@@ -379,8 +396,8 @@ class Phone(object):
             # pos = self.device.exists(Template(r"tpl1606822430589.png"))
             # if pos:
             #    self.device.touch(pos)
-            result = self.dev.exists(v=v)
-        return result or None
+            result = exists(v=v)
+        return result
 
     @airtest_exception_format
     def find_all(self, v: Template) -> t.List:
@@ -443,6 +460,55 @@ class Phone(object):
             result = self.dev.paste(*args, **kwargs)
         return result or None
 
+    @airtest_exception_format
+    def hide_keyword(self, file_name: str) -> None:
+        temp = self.get_cv_template(file_name=file_name)
+        hide_icon = self.find_all(v=temp)
+        if len(hide_icon) > 0:
+            logger.info("目前检测到键盘已打开，需要隐藏键盘，再做后续操作...")
+            self.touch(v=temp)
+        else:
+            hw_keyword = self.poco(type="android.widget.ImageView", name="com.android.systemui:id/back", desc="返回")
+            if isinstance(hw_keyword, UIObjectProxy) and hw_keyword.exists():
+                logger.info("目前检测到HW键盘已经打开，需要隐藏键盘，再做后续操作...")
+                hw_keyword.click()
+            else:
+                lg_keyword = self.poco(type="com.lge.ime.humaninterface.inputview.layout.HIGColoredEnterKey",
+                                       name="完成")
+                if isinstance(lg_keyword, UIObjectProxy) and lg_keyword.exists():
+                    logger.info("目前检测到LG键盘已经打开，需要隐藏键盘，再做后续操作...")
+                    lg_keyword.click()
+                else:
+                    logger.info("键盘已经隐藏，无需处理键盘...")
+
+    # 获取元素在屏幕上的绝对坐标
+    def get_abs_position(self, element: UIObjectProxy) -> t.Tuple:
+        screen_width, screen_height = get_screen_size_via_adb(device_id=self.device_id)
+        relative_position = element.get_position()
+        absolute_x = int(relative_position[0] * screen_width)
+        absolute_y = int(relative_position[1] * screen_height)
+        return absolute_x, absolute_y
+
+    # 快捷滑屏
+    def quick_slide_screen(self, duration: float = 0.5):
+        # 获取屏幕尺寸
+        screen_width, screen_height = get_screen_size_via_adb(device_id=self.device_id)
+        # 定义起始点和终止点坐标
+        start_x = screen_width // 2  # 屏幕中心点的横坐标
+        start_y = screen_height // 2  # 屏幕中心点的纵坐标
+        end_x = start_x  # 横坐标保持不变
+        end_y = screen_height // 4  # 终止点纵坐标为屏幕顶部 1/4 处
+        # 执行滑动操作
+        self.swipe((start_x, start_y), (end_x, end_y), duration=duration)
+
+
+class PocoProxy(object):
+
+    def __init__(self):
+        self.poco = AndroidUiautomationPoco(
+            use_airtest_input=True, screenshot_each_action=False, force_restart=True
+        )
+
     def get_po(self, type: str, name: str = '', text: str = '', desc: str = '', textMatches: str = '') -> UIObjectProxy:
         kwargs = dict()
         if type:
@@ -503,45 +569,3 @@ class Phone(object):
                 # pprint(get_ui_object_proxy_attr(ui_object_proxy=i))
                 po_list.append(i)
         return po_list
-
-    @airtest_exception_format
-    def hide_keyword(self, file_name: str) -> None:
-        temp = self.get_cv_template(file_name=file_name)
-        hide_icon = self.find_all(v=temp)
-        if len(hide_icon) > 0:
-            logger.info("目前检测到键盘已打开，需要隐藏键盘，再做后续操作...")
-            self.touch(v=temp)
-        else:
-            hw_keyword = self.poco(type="android.widget.ImageView", name="com.android.systemui:id/back", desc="返回")
-            if hw_keyword.exists():
-                logger.info("目前检测到HW键盘已经打开，需要隐藏键盘，再做后续操作...")
-                hw_keyword.click()
-            else:
-                lg_keyword = self.poco(type="com.lge.ime.humaninterface.inputview.layout.HIGColoredEnterKey",
-                                       name="完成")
-                if lg_keyword.exists():
-                    logger.info("目前检测到LG键盘已经打开，需要隐藏键盘，再做后续操作...")
-                    lg_keyword.click()
-                else:
-                    logger.info("键盘已经隐藏，无需处理键盘...")
-
-    # 获取元素在屏幕上的绝对坐标
-    @staticmethod
-    def get_abs_position(element: AndroidUiautomationPoco) -> t.Tuple:
-        screen_width, screen_height = get_screen_size_via_adb()
-        relative_position = element.get_position()
-        absolute_x = int(relative_position[0] * screen_width)
-        absolute_y = int(relative_position[1] * screen_height)
-        return absolute_x, absolute_y
-
-    # 快捷滑屏
-    def quick_slide_screen(self, duration: float = 0.5):
-        # 获取屏幕尺寸
-        screen_width, screen_height = get_screen_size_via_adb()
-        # 定义起始点和终止点坐标
-        start_x = screen_width // 2  # 屏幕中心点的横坐标
-        start_y = screen_height // 2  # 屏幕中心点的纵坐标
-        end_x = start_x  # 横坐标保持不变
-        end_y = screen_height // 4  # 终止点纵坐标为屏幕顶部 1/4 处
-        # 执行滑动操作
-        self.swipe((start_x, start_y), (end_x, end_y), duration=duration)
