@@ -13,7 +13,7 @@ from domain_service import CtripAppService
 
 
 def test_service():
-    app = CtripAppService()
+    app = CtripAppService(device_id="66J5T19627007749", enable_debug=False, platform="Android", port=0)
     app.device.wake()
     app.restart()
     app.hide_navigation_bar()
