@@ -9,8 +9,8 @@
 # Copyright ©2011-2024. Hunan xxxxxxx Company limited. All rights reserved.
 # ---------------------------------------------------------------------------------------------------------
 """
-from utils import logger
 from decimal import Decimal
+from capp_ui.libs import logger
 from capp_ui.fee import flight_fee
 
 __all__ = ["FlightTicketValidator"]
